@@ -2,13 +2,10 @@
 
 from distutils.core import setup
 
-long_desc = ''
+long_desc = 'Licensed under the generic MIT License.\"fresh-canvas\" can either be downloaded from the ' \
+            'Releases page on GitHub and manually added to PATH or installed via \"pip\".'
 prerelease_version = ''
 
-with open("README.md", "r", encoding="utf-8") as fh:
-    long_desc = fh.read()
-    fh.close()
-
 with open("version.txt", "r", encoding="utf-8") as fh:
     prerelease_version = fh.read()
     fh.close()
@@ -18,7 +15,7 @@ setup(name='fresh-canvas-prerelease',
       py_modules=['fresh-canvas'],
       description='Fresh Canvas [Pre-Release] | The Project Base',
       long_description=long_desc,
-      long_description_content_type="text/markdown",
+      long_description_content_type='text/markdown',
       author='Tushar Iyer',
       author_email='',
       url='https://github.com/tushariyer/fresh-canvas',
